tlslite.integration

Package tlslite :: Package integration |
[hide private]
[frames] | no frames]

# Source Code for Package tlslite.integration

     1  # Author: Trevor Perrin
     2  # See the LICENSE file for legal information regarding use of this file.
     3
     4  """Classes for integrating TLS Lite with other packages."""
     5
     6  __all__ = ["asyncstatemachine",
     7             "httptlsconnection",
     8             "pop3_tls",
     9             "imap4_tls",
    10             "smtp_tls",
    11             "xmlrpctransport",
    12             "tlssocketservermixin",
    13             "tlsasyncdispatchermixin"]
    14